@@ -5,7 +5,7 @@
 import timer
 t=timer.Timer() #初始化Timer对象
 do_something()
-t.printtime() #输出执行do_something()所用时间
+t.printtime() #输出执行do_something()所用时间 (使用t.gettime()获取所用时间更快)
 
 示例2:
 import timer
@@ -17,7 +17,7 @@ import time
 
 __email__="3416445406@qq.com"
 __author__="七分诚意 qq:3076711200 邮箱:%s"%__email__
-__version__="1.1"
+__version__="1.1.1"
 
 class Timer:
     "一个计时器类"
@@ -38,7 +38,7 @@ class Timer:
 
 def test():
     t=Timer()
-    t.printtime(fmt_str="计时器启动用时:{:.8f}秒")
+    t.printtime("调用printtime及启动用时:{:.8f}秒")
 
 if __name__=="__main__":
     test()
